@@ -1,24 +1,26 @@
 <?php
 
 $title = get_sub_field("title") ?? "";
+$sectionBSClass = get_sub_field("section_bs_class") ?? "";
 
 ?>
-<div class="section section--banner-slider">
+<div class="section section--banner-slider <?= $sectionBSClass; ?>">
     <div class="container">
-        <?= $title !== "" ? "<h2 class='accent'>".$title."</h2>" : "" ; ?> 
+        <?= $title !== "" ? "<h2 class='accent'>".$title."</h2>" : "" ; ?>
         <div class="row">
         <?php
         if (have_rows('slides')) {
+            $i = 0;
             ?>
             <div class="swiper-pagination"></div>
             <div class="swiper-container banner-slider-swiper">
-                <div class="swiper-wrapper" style="height: 430px;">   
+                <div class="swiper-wrapper" style="">
                     <?php
-                    while (have_rows('slides')) { 
+                    while (have_rows('slides')) {
                         the_row();
 
                         $type = get_sub_field("type") ?? "";
-                    
+                        $i++;
                         if ($type == "side") {
 
                             $side = get_sub_field("side") ?? "";
@@ -38,19 +40,19 @@ $title = get_sub_field("title") ?? "";
                             }
 
                             ?>
-                            <div class="banner-slide-side swiper-slide">
+                            <div class="banner-slide-side swiper-slide slide-no--<?=$i;?>">
                                 <div class="container-fluid">
                                     <div class="row">
                                         <div class="col-lg-4 col-xxl-3 order-2 small-side <?= $smallSideClass ?>">
-                                            <?= $sideTitle !== "" ? "<h3 class='accent'>".$sideTitle."</h3>" : "" ; ?> 
-                                            <?= $sideText !== "" ? "<p>".$sideText."</p>" : "" ; ?> 
+                                            <?= $sideTitle !== "" ? "<h3 class='accent'>".$sideTitle."</h3>" : "" ; ?>
+                                            <?= $sideText !== "" ? "<p>".$sideText."</p>" : "" ; ?>
                                             <?= $sideLinkText !== "" ? "<a href='".$sideLink."'><span class='cac-btn-graphic--alt btn-graphic--alt accent'>".$sideLinkText."</span></a>" : "" ; ?>
                                             <?php if($secondaryImgLink) {?>
                                                 <a class="left--link" href="<?=$secondaryImgLink;?>">
                                             <?php
                                                 }
                                             ?>
-                                            <?= $sideSecondaryImage !== "" ? "<img class='". $side."' src='".$sideSecondaryImage."'/>" : "" ; ?> 
+                                            <?= $sideSecondaryImage !== "" ? "<img class='". $side."' src='".$sideSecondaryImage."'/>" : "" ; ?>
                                              <?php if($secondaryImgLink){?>
                                                 </a>
                                             <?php
@@ -63,7 +65,7 @@ $title = get_sub_field("title") ?? "";
                                             <?php
                                                 }
                                             ?>
-                                            <?= $sidePrimaryImage !== "" ? "<img class='banner-height-el' src='".$sidePrimaryImage."'/>" : "" ; ?> 
+                                            <?= $sidePrimaryImage !== "" ? "<img class='banner-height-el' src='".$sidePrimaryImage."'/>" : "" ; ?>
                                             <?php if($sideLink){?>
                                                 </a>
                                             <?php
@@ -83,7 +85,7 @@ $title = get_sub_field("title") ?? "";
                             $centreLink = get_sub_field("centre_link") ?? "";
                             $centreLinkText = get_sub_field("centre_link_text") ?? "";
 
-                            
+
 
                             ?>
                             <div class="banner-slide-center swiper-slide">
@@ -91,16 +93,16 @@ $title = get_sub_field("title") ?? "";
                                     <div class="row">
                                         <div class="container banner-height-el banner-height-el--centered">
                                             <div class="row">
-                                            <?= $centreTitle !== "" ? "<h3 class='col-12 accent'>".$centreTitle."</h3>" : "" ; ?> 
-                                            <?= $centerText !== "" ? "<p class='col-12'>".$centerText."</p>" : "" ; ?> 
+                                            <?= $centreTitle !== "" ? "<h3 class='col-12 accent'>".$centreTitle."</h3>" : "" ; ?>
+                                            <?= $centerText !== "" ? "<p class='col-12'>".$centerText."</p>" : "" ; ?>
                                             <?= $centreLinkText !== "" ? "<a class='col-12' href='".$centreLink."'><span class='cac-btn-graphic--alt btn-graphic--alt accent'>".$centreLinkText."</span></a>" : "" ; ?>
-                                                
+
                                                 <?php
                                                 if( have_rows('center_logos') ) {
                                                     ?>
                                                     <div class="banner-slide-logos col-12">
                                                     <?php
-                                                        while ( have_rows('center_logos') ) { 
+                                                        while ( have_rows('center_logos') ) {
                                                             the_row();
                                                             $logo = get_sub_field("logo") ?? "";
                                                             $link = get_sub_field("link");
@@ -117,7 +119,7 @@ $title = get_sub_field("title") ?? "";
                                                                 <?php
                                                                     if($link){?>
                                                                 </a>
-                                                                
+
                                                             <?php
                                                                 }else{
                                                                     ?>
@@ -137,6 +139,84 @@ $title = get_sub_field("title") ?? "";
                             </div>
                             <?php
 
+                        } else if ($type == "product") {
+
+                            $productImage = get_sub_field("product_image") ?? "";
+                            $productPackagingImage = get_sub_field("product_packaging_image") ?? "";
+                            $productPackagingLink = get_sub_field("product_packaging_link") ?? "";
+                            $productCta1Text = get_sub_field("product_cta_1_text") ?? "";
+                            $productCta1Link = get_sub_field("product_cta_1_link") ?? "";
+                            $productCta2Text = get_sub_field("product_cta_2_text") ?? "";
+                            $productCta2Link = get_sub_field("product_cta_2_link") ?? "";
+                            $centerText = get_sub_field("center_text") ?? "";
+                            $centreLink = get_sub_field("centre_link") ?? "";
+                            $productAwards = get_sub_field("product_awards") ?? "";
+
+                            ?>
+                            <div class="banner-slide-product swiper-slide">
+                                <div class="container-fluid" style="background-image: url('<?= $productImage ?>')">
+                                    <div class="row">
+
+                                        <?php
+                                        if( $productPackagingImage !== "" ) {
+                                            ?>
+                                            <div class="col-12 col-md-5 product-slide-item product-packaging-image">
+                                                <?php
+                                                    if( $productPackagingLink !== "" ) {
+                                                        ?>
+                                                        <a href="<?= $productPackagingLink ?>">
+                                                        <?php
+                                                    }
+                                                        ?>
+                                                            <img src="<?=$productPackagingImage?>"></img>
+                                                        <?php
+                                                    if( $productPackagingLink !== "" ) {
+                                                        ?>
+                                                        </a>
+                                                        <?php
+                                                    }
+                                                ?>
+                                            </div>
+                                            <?php
+                                        }
+                                        ?>
+                                        <div class="col-12 col-md-4 product-slide-item product-slide-item-ctas">
+                                            <?php
+                                            if( $productCta1Link !== "" && $productCta1Text !== "" ) {
+                                                ?>
+                                                    <a href="<?=$productCta1Link?>"><?= $productCta1Text ?></a>
+                                                <?php
+                                            }
+                                            if( $productCta2Link !== "" && $productCta2Text !== "" ) {
+                                                ?>
+                                                    <a href="<?=$productCta2Link?>"><?= $productCta2Text ?></a>
+                                                <?php
+                                            }
+                                            ?>
+                                        </div>
+                                        <?php
+                                        if( have_rows('product_awards') ) {
+                                            ?>
+                                            <div class="col-12 col-md-3 product-slide-item product-slide-item-icon">
+                                                <?php
+                                                while ( have_rows('product_awards') ) {
+                                                    the_row();
+                                                    $icon = get_sub_field("icon") ?? "";
+                                                    if($icon){
+                                                    ?>
+                                                            <img src="<?= $icon; ?>"/>
+                                                    <?php
+                                                    }
+                                                }
+                                                ?>
+                                            </div>
+                                            <?php
+                                        }
+                                        ?>
+                                    </div>
+                                </div>
+                            </div>
+                            <?php
                         }
                     }
                     ?>
@@ -150,5 +230,22 @@ $title = get_sub_field("title") ?? "";
             <div class="swiper-button-next swiper-button-next--banner"></div>
             <div class="swiper-button-prev swiper-button-prev--banner"></div>
         </div>
+        <?php
+            if( have_rows('call_to_action_buttons') ){
+            ?>
+            <div class="flex-fill align-self-center text-center banner-slider__cta-row">
+                <?php
+                while( have_rows('call_to_action_buttons') ){
+                    the_row();
+                    $cta = get_sub_field('call_to_action');
+                    ?>
+                    <a class="btn btn-graphic" href="<?=$cta['url'];?>" target="<?=$cta['target'];?>"><?= $cta['title']; ?></a>
+                    <?php
+                }
+            ?>
+            </div>
+            <?php
+            }
+		?>
     </div>
 </div>
\ No newline at end of file
